export interface Activation {
    /**
     * Activation ID
     * @format GUID
     */
    id?: string;
    /** Activation automation */
    automation?: Automation;
}
export interface Automation extends AutomationOriginInfoOneOf {
    /** When the origin of the automation is `APPLICATION`, the details of the app that created it. */
    applicationInfo?: ApplicationOrigin;
    /** When the origin of the automation is `PREINSTALLED`, the details of the preinstalled automation. */
    preinstalledInfo?: PreinstalledOrigin;
    /**
     * Automation ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Revision number. This increments by 1 whenever the automation is updated. Specify the current revision number whenever updating an existing automation.
     * @readonly
     */
    revision?: string | null;
    /**
     * Who created the automation.
     * @immutable
     * @readonly
     */
    createdBy?: AuditInfo;
    /**
     * When the automation was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Who last updated the automation.
     * @readonly
     */
    updatedBy?: AuditInfo;
    /**
     * When the automation was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Automation name as displayed on the user's site.
     * @minLength 1
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description.
     * @maxLength 2000
     */
    description?: string | null;
    /** Automation configuration. */
    configuration?: AutomationConfiguration;
    /**
     * How the automation was added to the user's site.
     * @immutable
     */
    origin?: Origin;
    /** Automation settings. */
    settings?: AutomationSettings;
    /**
     * When the automation is a draft, the draft details.
     * @readonly
     */
    draftInfo?: DraftInfo;
    /**
     * Whether the automation is archived.
     *
     * To archive an automation, set this to `true`. To restore an archived automation, set this to `false`.
     */
    archived?: boolean;
}
/** @oneof */
export interface AutomationOriginInfoOneOf {
    /** When the origin of the automation is `APPLICATION`, the details of the app that created it. */
    applicationInfo?: ApplicationOrigin;
    /** When the origin of the automation is `PREINSTALLED`, the details of the preinstalled automation. */
    preinstalledInfo?: PreinstalledOrigin;
}
export interface ActionSettings {
    /**
     * Permanent actions. Permanent actions cannot be deleted.
     *
     * When empty, all actions can be deleted by the user.
     * @maxSize 30
     * @format GUID
     */
    permanentActionIds?: string[];
    /**
     * Read-only actions. Read-only actions cannot be edited.
     *
     * When empty, all actions are editable.
     * @maxSize 30
     * @format GUID
     */
    readonlyActionIds?: string[];
    /**
     * Whether to disable the ability to add a delay to the automation.
     *
     * Default: `false`.
     */
    disableDelayAddition?: boolean;
    /**
     * Whether to disable the ability to add a condition to the automation.
     *
     * Default: `false`.
     */
    disableConditionAddition?: boolean;
}
export declare enum Domain {
    /** User domain (default). */
    USER = "USER",
    /** Wix domain. */
    WIX = "WIX",
    /** Wix account-level domain. */
    WIX_ACCOUNT = "WIX_ACCOUNT"
}
export interface Enrichment {
    /**
     * Enrichment input mappings.
     * @maxSize 2
     */
    inputMappings?: Record<string, any>[] | null;
}
export interface AuditInfo extends AuditInfoIdOneOf {
    /**
     * [User ID](https://dev.wix.com/docs/build-apps/get-started/overview/glossary#user-id).
     * @format GUID
     */
    userId?: string;
    /**
     * [App ID](https://dev.wix.com/docs/build-apps/get-started/overview/glossary#app-id).
     *
     * You can find the app ID on the [Home page](https://manage.wix.com/app-selector?title=Select+an+App&primaryButtonText=Select+Site&actionUrl=https%3A%2F%2Fdev.wix.com%2Fapps%2F%7BappId%7D%home) in the app's dashboard.
     * @format GUID
     */
    appId?: string;
}
/** @oneof */
export interface AuditInfoIdOneOf {
    /**
     * [User ID](https://dev.wix.com/docs/build-apps/get-started/overview/glossary#user-id).
     * @format GUID
     */
    userId?: string;
    /**
     * [App ID](https://dev.wix.com/docs/build-apps/get-started/overview/glossary#app-id).
     *
     * You can find the app ID on the [Home page](https://manage.wix.com/app-selector?title=Select+an+App&primaryButtonText=Select+Site&actionUrl=https%3A%2F%2Fdev.wix.com%2Fapps%2F%7BappId%7D%home) in the app's dashboard.
     * @format GUID
     */
    appId?: string;
}
export interface AutomationConfiguration {
    /** Status of the automation on the site. */
    status?: AutomationConfigurationStatus;
    /** Trigger configuration. */
    trigger?: Trigger;
    /**
     * Root action IDs. A root action is the first action that runs after the trigger occurs. Root actions run in parallel.
     *
     * > **Note**: You can currently only specify 1 root action.
     * @maxSize 20
     * @format GUID
     */
    rootActionIds?: string[];
    /** Actions the automation can execute, as key:value pairs. For the key, specify the action ID. The value must be an object structured as described below. */
    actions?: Record<string, AutomationConfigurationAction>;
}
export declare enum TimeUnit {
    UNKNOWN_TIME_UNIT = "UNKNOWN_TIME_UNIT",
    /** Minutes. */
    MINUTES = "MINUTES",
    /** Hours. */
    HOURS = "HOURS",
    /** Days. */
    DAYS = "DAYS",
    /** Weeks. */
    WEEKS = "WEEKS",
    /** Months. */
    MONTHS = "MONTHS"
}
export interface Filter {
    /**
     * Filter ID.
     * @format GUID
     */
    id?: string;
    /**
     * Field key.
     *
     * You can find the field key in [the trigger payload schema](https://dev.wix.com/docs/rest/business-management/automations/triggers/the-trigger-payload-schema).
     * @minLength 1
     * @maxLength 110
     */
    fieldKey?: string;
    /**
     * Filter expression.
     *
     * For the automation to run, the expression must evaluate to `true`.
     * @maxLength 2500
     */
    filterExpression?: string;
}
export interface FutureDateActivationOffset {
    /**
     * Amount of time before the trigger to run the automation.
     *
     * > **Note**: To delay an automation after the trigger event occurs, use a [delay action](https://dev.wix.com/docs/rest/business-management/automations/automations/automations-v2/about-automation-configuration#delay-action).
     * @maxLength 1000
     */
    preScheduledEventOffsetExpression?: string;
    /** Unit in which to set the action offset. */
    scheduledEventOffsetTimeUnit?: TimeUnit;
}
export interface RateLimit {
    /**
     * Maximum number of times the trigger can be activated.
     * @maxLength 1000
     */
    maxActivationsExpression?: string;
    /**
     * Duration of the rate limit. The rate limit applies for the specified duration and then expires.
     *
     * When empty, the rate limit does not expire.
     * @maxLength 1000
     */
    durationExpression?: string | null;
    /** Unit in which to set the duration of the rate limit. */
    durationTimeUnit?: TimeUnit;
    /**
     * Activation identifier used to count the number of activations.
     * @minLength 1
     * @maxLength 400
     */
    uniqueIdentifierExpression?: string | null;
}
export interface FilterValueSelection {
    /**
     * Values that can help the user filter certain automations. Specify values in the following format: `<filter_id>__<selected_value>`.
     * @maxLength 80
     * @maxSize 50
     */
    selectedFilterValues?: string[];
}
export interface ConditionExpressionGroup {
    /** Logical operator used to evaluate the condition expressions. */
    operator?: Operator;
    /**
     * Expressions evaluated using the selected operator.
     * @minSize 1
     * @maxSize 20
     * @maxLength 2500
     */
    booleanExpressions?: string[];
}
export declare enum Operator {
    /** Unknown. */
    UNKNOWN_OPERATOR = "UNKNOWN_OPERATOR",
    /** `OR` operator. */
    OR = "OR",
    /** `AND` operator. */
    AND = "AND"
}
export interface ActionCodeSnippet {
    /** Logical operator used to evaluate the condition expressions. */
    language?: CodeSnippetLanguage;
    /**
     * Expressions evaluated using the selected operator. this code should comply the language syntax. and format
     * @maxLength 1000
     */
    code?: string;
}
export declare enum CodeSnippetLanguage {
    /** Unknown. */
    UNKNOWN_LANGUAGE = "UNKNOWN_LANGUAGE",
    /** `JAVASCRIPT` language. */
    JAVASCRIPT = "JAVASCRIPT"
}
/** Path definition */
export interface Path {
    /**
     * Unique path ID.
     * @format GUID
     */
    id?: string;
    /**
     * Path display name.
     * @minLength 1
     * @maxLength 100
     */
    name?: string;
    /**
     * ID of the action to run when this path is taken.
     * @format GUID
     */
    postActionId?: string | null;
}
export declare enum Type {
    /** Based on the trigger. */
    UNKNOWN_ACTION_TYPE = "UNKNOWN_ACTION_TYPE",
    /** Defined by a [Wix app](https://dev.wix.com/docs/rest/business-management/automations/automations/automations-v2/about-automation-configuration#app-defined-actions). This action type is available in the site dashboard. */
    APP_DEFINED = "APP_DEFINED",
    /** Condition. This determines which action runs next. */
    CONDITION = "CONDITION",
    /** Delay. The automation must wait before executing the next step. */
    DELAY = "DELAY",
    /** Rate-limiter. This stops the automation flow if the subsequent action has reached its maximum allowed executions. */
    RATE_LIMIT = "RATE_LIMIT"
}
export interface AppDefinedAction {
    /**
     * ID of the app that defines the action.
     * @format GUID
     */
    appId?: string;
    /**
     * Action key.
     * @minLength 1
     * @maxLength 100
     */
    actionKey?: string;
    /** Action input mapping as defined in the action's [input schema](https://dev.wix.com/docs/rest/business-management/automations/actions/the-action-input-schema). */
    inputMapping?: Record<string, any> | null;
    /**
     * Action skip conditions. An action is skipped if any of the specified conditions evaluates to `true`.
     *
     * > **Note**: Actions that follow a skipped action still run.
     * @maxSize 10
     */
    skipConditionOrExpressionGroups?: ConditionExpressionGroup[];
    /**
     * IDs of actions that run in parallel after the action completes.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
    /** Action output schema. When specified, this replaces the action schema. */
    overrideOutputSchema?: Record<string, any> | null;
}
export interface ConditionAction {
    /**
     * Condition is `true` if one or more of the expression groups evaluates to `true`.
     * @minSize 1
     * @maxSize 10
     */
    orExpressionGroups?: ConditionExpressionGroup[];
    /**
     * IDs of actions to run when the condition evaluates to `true`.
     * @maxSize 20
     * @format GUID
     */
    truePostActionIds?: string[];
    /**
     * IDs of actions to run when the condition evaluates to `false`.
     * @maxSize 20
     * @format GUID
     */
    falsePostActionIds?: string[];
}
export interface CodeConditionAction {
    /** condition code. This is a code that can be used to identify the condition in the automation. code should return a boolean value. otherwise the value will be tried to be casted to boolean. */
    snippet?: ActionCodeSnippet;
    /**
     * IDs of actions to run when the condition evaluates to `true`.
     * @maxSize 20
     * @format GUID
     */
    truePostActionIds?: string[];
    /**
     * IDs of actions to run when the condition evaluates to `false`.
     * @maxSize 20
     * @format GUID
     */
    falsePostActionIds?: string[];
}
export interface DelayAction {
    /**
     * Time to wait before running the action. The wait time starts from when the current action completes.
     *
     * > **Note**: To define the wait time from a specific moment in time, use `dueDateEpochExpression`.
     * @maxLength 1000
     */
    offsetExpression?: string | null;
    /** Unit in which to set the wait time to wait before the action runs. */
    offsetTimeUnit?: TimeUnit;
    /**
     * Action run date in milliseconds elapsed since January 1, 1970 UTC.
     *
     * > **Note**: If an `offsetExpression` is defined, the delay is calculated from the time of the offset.
     * @maxLength 1000
     */
    dueDateEpochExpression?: string | null;
    /**
     * IDs of actions to run in parallel after the time delay.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface RateLimitAction {
    /**
     * Maximum number of times the action can run.
     * @maxLength 1000
     */
    maxActivationsExpression?: string;
    /**
     * Rate limit duration.
     *
     * When empty, the rate limit does not expire.
     * @maxLength 1000
     */
    rateLimitDurationExpression?: string | null;
    /** Unit in which to set the duration of the rate limit. */
    rateLimitDurationTimeUnit?: TimeUnit;
    /**
     * Unique identifier of each activation by which rate limiter counts activations.
     * @minLength 1
     * @maxLength 400
     */
    uniqueIdentifierExpression?: string | null;
    /**
     * IDs of actions to run in parallel after the action completes.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface SetVariablesAction {
    /** Output mapping. For example: `{"someField": "{{10}}", "someOtherField": "{{multiply( var('account.points.balance') ;2 )}}" }`. */
    outputMapping?: Record<string, any> | null;
    /**
     * Output JSON schema representation.
     *
     * > **Note**: To minimize request size, you can also specify a string.
     */
    outputSchema?: Record<string, any> | null;
    /**
     * IDs of actions to run in parallel after variable initialization.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface OutputAction {
    /** Output action output mapping. */
    outputMapping?: Record<string, any> | null;
}
export interface SplitAction {
    /**
     * List of paths to split execution into.
     * @minSize 2
     * @maxSize 10
     */
    paths?: Path[];
}
export declare enum AutomationConfigurationStatus {
    /** Unknown. */
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** Active. Active automations can be triggered. */
    ACTIVE = "ACTIVE",
    /** Inactive. Inactive automations cannot be triggered. */
    INACTIVE = "INACTIVE"
}
export interface Trigger {
    /**
     * ID of the app that defines the trigger.
     * @format GUID
     */
    appId?: string;
    /**
     * Trigger key.
     *
     * Learn about [setting up a trigger](https://dev.wix.com/docs/rest/business-management/automations/triggers/add-a-trigger-to-your-app#step-1--set-up-the-trigger).
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /**
     * Schema field filters. All filter conditions must be met for the automation to run.
     *
     * Learn more about setting up [automation filters](https://dev.wix.com/docs/rest/business-management/automations/automations/automations-v2/about-automation-configuration#filters).
     * @maxSize 5
     */
    filters?: Filter[];
    /**
     * Automation offset. You can schedule automations to run before the trigger occurs.
     *
     * Learn more about [scheduled events](https://dev.wix.com/docs/rest/business-management/automations/automations/automations-v2/configure-your-automation#scheduled-events).
     */
    scheduledEventOffset?: FutureDateActivationOffset;
    /** Limit on the number of times an automation can be triggered. */
    rateLimit?: RateLimit;
    /** Trigger schema override. When specified, this replaces the trigger schema. */
    overrideSchema?: Record<string, any> | null;
}
export interface AutomationConfigurationAction extends AutomationConfigurationActionInfoOneOf {
    /** Details of the action when its `type` is `APP_DEFINED`. */
    appDefinedInfo?: AppDefinedAction;
    /** Details of the action when its `type` is `CONDITION`. */
    conditionInfo?: ConditionAction;
    /** Details of the action when its `type` is `CODE_CONDITION`. */
    codeConditionInfo?: CodeConditionAction;
    /** Details of the action when its `type` is `DELAY`. */
    delayInfo?: DelayAction;
    /** Details of the action when its `type` is `RATE_LIMIT`. */
    rateLimitInfo?: RateLimitAction;
    /**
     * Action ID.
     *
     * If not specified, automatically generated by Wix.
     * @format GUID
     */
    id?: string | null;
    /** [Action type](https://dev.wix.com/docs/rest/business-management/automations/automations/automations-v2/about-automation-configuration#action-type). */
    type?: Type;
    /**
     * [Action namespace](https://dev.wix.com/docs/rest/business-management/automations/automations/automations-v2/about-automation-configuration#namespace). This differentiates it from other actions of the same type.
     *
     * If the action outputs any data, the data appears under the namespace in the payload sent to the subsequent steps in the automation. If the user has multiple actions with the same `appId` and `actionKey`, the output of the previous action is overwritten.
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
}
/** @oneof */
export interface AutomationConfigurationActionInfoOneOf {
    /** Details of the action when its `type` is `APP_DEFINED`. */
    appDefinedInfo?: AppDefinedAction;
    /** Details of the action when its `type` is `CONDITION`. */
    conditionInfo?: ConditionAction;
    /** Details of the action when its `type` is `CODE_CONDITION`. */
    codeConditionInfo?: CodeConditionAction;
    /** Details of the action when its `type` is `DELAY`. */
    delayInfo?: DelayAction;
    /** Details of the action when its `type` is `RATE_LIMIT`. */
    rateLimitInfo?: RateLimitAction;
}
export interface FilterableAppDefinedActions {
    /**
     * App-defined action identifiers. Identifiers have the following format: `${appId}_${actionKey}`.
     * @minSize 1
     * @maxSize 100
     * @minLength 1
     * @maxLength 150
     */
    actionIdentifiers?: string[];
}
export declare enum Origin {
    /** Default value. */
    UNKNOWN_ORIGIN = "UNKNOWN_ORIGIN",
    /** Created by a [Wix user](https://dev.wix.com/docs/build-apps/get-started/overview/glossary#wix-user). */
    USER = "USER",
    /** Created by a [Wix app](https://dev.wix.com/docs/build-apps/get-started/overview/glossary#wix-app) for a particular site. */
    APPLICATION = "APPLICATION",
    /** [Preinstalled automation](https://dev.wix.com/docs/build-apps/develop-your-app/extensions/backend-extensions/automations/pre-installed-automations/about-pre-installed-automations). */
    PREINSTALLED = "PREINSTALLED"
}
export interface ApplicationOrigin {
    /**
     * [App ID](https://dev.wix.com/docs/build-apps/get-started/overview/glossary#app-id).
     *
     * You can find the app ID on the [Home page](https://manage.wix.com/app-selector?title=Select+an+App&primaryButtonText=Select+Site&actionUrl=https%3A%2F%2Fdev.wix.com%2Fapps%2F%7BappId%7D%home) in the app's dashboard.
     * @format GUID
     */
    appId?: string;
}
export interface PreinstalledOrigin {
    /**
     * ID of the app that added the [preinstalled automation](https://dev.wix.com/docs/build-apps/develop-your-app/extensions/backend-extensions/automations/pre-installed-automations/about-pre-installed-automations).
     * @format GUID
     */
    appId?: string;
    /**
     * Whether the automation is an override.
     *
     * When a user modifies the preinstalled automation installed on their site, a site-specific version of the automation is created that overrides the automation that was originally installed. This override automation has the same automation ID as the original preinstalled automation.
     *
     * > **Note**: An override automation can no longer be updated by the app that originally installed it.
     * >
     * > To revert to the original preinstalled version, the user must delete the override by calling the Delete Automation method. Calling Delete Automation on an override automation removes the override method and restores the preinstalled automation that was previously installed.
     *
     * Default: `false`.
     * @immutable
     * @readonly
     */
    override?: boolean | null;
}
export interface AutomationSettings {
    /**
     * Whether the automation is hidden from users.
     *
     * Default: `false`
     */
    hidden?: boolean;
    /**
     * Whether the automation is read-only.
     *
     * Default: `false`
     */
    readonly?: boolean;
    /**
     * Whether to disable the option to delete the automation from the site.
     *
     * Default: `false`.
     */
    disableDelete?: boolean;
    /**
     * Whether to disable the option to change the automation's `configuration.status`, for example from `ACTIVE` to `INACTIVE`.
     *
     * Default: `false`.
     */
    disableStatusChange?: boolean;
    /** Automation action settings. */
    actionSettings?: ActionSettings;
}
export interface DraftInfo {
    /**
     * ID of the original automation.
     * @format GUID
     * @readonly
     */
    originalAutomationId?: string | null;
}
export interface Enrichments {
    /** Whether the studio site enrichment is wanted. */
    studioSite?: Enrichment;
}
export interface ExtendedFields {
    /**
     * Extended field data. Each key corresponds to the namespace of the app that created the extended fields.
     * The value of each key is structured according to the schema defined when the extended fields were configured.
     *
     * You can only access fields for which you have the appropriate permissions.
     *
     * Learn more about [extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields).
     */
    namespaces?: Record<string, Record<string, any>>;
}
export interface ActivationStatusChanged extends ActivationStatusChangedStatusInfoOneOf {
    /** Initiated status information */
    initiatedInfo?: InitiatedStatusInfo;
    /** Started status information */
    startedInfo?: ActivationStatusChangedStartedStatusInfo;
    /** Scheduled status information */
    scheduledInfo?: ScheduledStatusInfo;
    /** Cancelled status information */
    cancelledInfo?: CancelledStatusInfo;
    /** Failed status information */
    failedInfo?: ActivationStatusChangedFailedStatusInfo;
    /** Skipped status information */
    skippedInfo?: SkippedStatusInfo;
    /** Activation */
    activation?: Activation;
    /** Activation status */
    status?: ActivationStatusChangedStatus;
    /** Change event created date */
    statusChangedDate?: Date | null;
}
/** @oneof */
export interface ActivationStatusChangedStatusInfoOneOf {
    /** Initiated status information */
    initiatedInfo?: InitiatedStatusInfo;
    /** Started status information */
    startedInfo?: ActivationStatusChangedStartedStatusInfo;
    /** Scheduled status information */
    scheduledInfo?: ScheduledStatusInfo;
    /** Cancelled status information */
    cancelledInfo?: CancelledStatusInfo;
    /** Failed status information */
    failedInfo?: ActivationStatusChangedFailedStatusInfo;
    /** Skipped status information */
    skippedInfo?: SkippedStatusInfo;
}
export declare enum Target {
    UNKNOWN_TARGET = "UNKNOWN_TARGET",
    SCHEDULE = "SCHEDULE",
    IMMEDIATE = "IMMEDIATE"
}
export declare enum CancellationReason {
    UNKNOWN_CANCELLATION_REASON = "UNKNOWN_CANCELLATION_REASON",
    /** Indicates that the activation was cancelled directly. */
    EVENT_CANCELLED = "EVENT_CANCELLED",
    /** Indicates that the activation was cancelled because the automation was deactivated. */
    AUTOMATION_DEACTIVATED = "AUTOMATION_DEACTIVATED",
    /** Indicates that the activation was cancelled because the automation was deleted. */
    AUTOMATION_DELETED = "AUTOMATION_DELETED",
    /** Indicates that the activation was cancelled after the automation schedule time was reached. */
    CANCELLED_BY_REFRESH_PAYLOAD = "CANCELLED_BY_REFRESH_PAYLOAD",
    /** Indicates that the activation was cancelled due to a UoU GDPR "Right to be Forgotten" request. */
    CANCELLED_BY_GDPR_REQUEST = "CANCELLED_BY_GDPR_REQUEST"
}
export interface Identity {
    /**
     * User ID
     * @format GUID
     */
    userId?: string | null;
    /**
     * App ID
     * @format GUID
     */
    appId?: string | null;
}
export declare enum ErrorReason {
    /** Unexpected error reason */
    UNEXPECTED_ERROR_REASON = "UNEXPECTED_ERROR_REASON",
    /** Failed to evaluate the schedule date expression */
    SCHEDULE_DATE_EVALUATION_FAILED = "SCHEDULE_DATE_EVALUATION_FAILED"
}
export declare enum SkipReason {
    UNKNOWN_SKIP_REASON = "UNKNOWN_SKIP_REASON",
    /** Activation was skipped because the scheduled execution time had already passed at the time of execution. */
    SCHEDULE_DATE_EXPIRED = "SCHEDULE_DATE_EXPIRED",
    /** Activation was skipped because the trigger filters defined in the automation did not match the payload. */
    TRIGGER_FILTERS_NOT_PASSED = "TRIGGER_FILTERS_NOT_PASSED",
    /** Activation was skipped because it exceeded the configured rate limit (maximum number of executions allowed in a time period). */
    RATE_LIMIT_EXCEEDED = "RATE_LIMIT_EXCEEDED",
    /** Activation was skipped because an event with the same idempotency key was already processed. */
    EVENT_ALREADY_PROCESSED = "EVENT_ALREADY_PROCESSED"
}
export declare enum ActivationStatusChangedStatus {
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** Indicates that activation has not started yet and no actions have been executed. */
    INITIATED = "INITIATED",
    /** Activation is in scheduled status when the automation has a future date or debounce defined and we're in the waiting stage and no actions have been executed. */
    SCHEDULED = "SCHEDULED",
    /** Indicates the automation activation has started and is currently in progress. */
    STARTED = "STARTED",
    /** Indicates all the automation actions were handled either by invoking them, skipping them, etc. */
    ENDED = "ENDED",
    /** Indicates the activation was cancelled. */
    CANCELLED = "CANCELLED",
    /**
     * Indicates the activation failed to start.
     * Note that failure in the activation of a single action will not result in a failure in activation of the entire automation.
     */
    FAILED = "FAILED",
    /**
     * Indicates that the automation activation was skipped without executing any actions.
     * Note that an activation will either be skipped immediately or move to INITIATED state.
     */
    SKIPPED = "SKIPPED"
}
export interface Metadata {
    /**
     * Identity field keys that are collected from the trigger payload schema, including contact and member ids
     * @maxSize 100
     * @maxLength 100
     */
    identityFieldKeys?: string[];
}
export interface InitiatedStatusInfo {
    /** Activation target */
    target?: Target;
    /** Event payload */
    payload?: Record<string, any> | null;
    /**
     * External entity ID
     * @maxLength 40
     */
    externalEntityId?: string | null;
    /**
     * Unique identifier for the request that initiated the automation
     * @maxLength 100
     */
    requestId?: string;
}
export interface ActivationStatusChangedStartedStatusInfo {
    /** Enriched and refreshed payload */
    payload?: Record<string, any> | null;
}
export interface ScheduledStatusInfo {
    /**
     * Schedule identifier
     * @format GUID
     */
    scheduleId?: string;
    /** Indicates when the activation should start */
    date?: Date | null;
}
export interface CancelledStatusInfo {
    /** Cancellation reason */
    reason?: CancellationReason;
    /** Identity (such as user, app, etc.) that caused the cancellation. */
    initiator?: Identity;
}
export interface ActivationStatusChangedFailedStatusInfo {
    /**
     * Error description
     * @maxLength 1000
     * @readonly
     */
    errorDescription?: string;
    /**
     * Error code
     * @maxLength 20
     * @readonly
     */
    errorCode?: string | null;
    /** Error reason */
    errorReason?: ErrorReason;
    /** Event payload */
    payload?: Record<string, any> | null;
    /**
     * External entity ID
     * @maxLength 40
     */
    externalEntityId?: string | null;
    /**
     * Unique identifier for the request that initiated the automation
     * @maxLength 100
     */
    requestId?: string | null;
}
export interface SkippedStatusInfo {
    /** The reason why the automation activation was skipped */
    reason?: SkipReason;
    /** Event payload */
    payload?: Record<string, any> | null;
    /**
     * External entity ID
     * @maxLength 40
     */
    externalEntityId?: string | null;
    /**
     * Unique identifier for the request that initiated the automation
     * @maxLength 100
     */
    requestId?: string;
}
export interface ScheduleRequest {
    schedule?: Schedule;
}
export interface Schedule {
    /**
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * doesn't have to be unique. example: triggerName+entityId
     * @maxLength 300
     */
    identifier?: string;
    /** @format GUID */
    configurationCorrelationId?: string;
    /** @format GUID */
    activationId?: string;
    scheduledAction?: ScheduledAction;
    /** Raw domain event, not enriched */
    eventPayload?: string;
    /** @readonly */
    scheduleStatus?: ScheduleStatus;
    /** @readonly */
    scheduleDate?: Date | null;
    /** @readonly */
    createdDate?: Date | null;
    /** @readonly */
    updatedDate?: Date | null;
    overrideable?: boolean | null;
    triggerInfo?: TriggerInfo;
    automation?: Automation;
}
export interface ScheduledAction {
    /**
     * Action's id.
     * @format GUID
     */
    id?: string;
    /** decide how long we should wait */
    delay?: Delay;
}
export interface Delay extends DelayOfOneOf {
    simple?: SimpleDelay;
    /**
     * jsonata expression - sleep until the given date
     * for example: $toMillis(MyObject.Date) + 2*1000*60*60*24) -> will schedule 2 days after MyObject.Date
     * @maxLength 300
     */
    dateExpression?: string;
}
/** @oneof */
export interface DelayOfOneOf {
    simple?: SimpleDelay;
    /**
     * jsonata expression - sleep until the given date
     * for example: $toMillis(MyObject.Date) + 2*1000*60*60*24) -> will schedule 2 days after MyObject.Date
     * @maxLength 300
     */
    dateExpression?: string;
}
export interface SimpleDelay {
    value?: number;
    units?: Units;
    /**
     * Optional, used if provided: Jsonata expression that evaluates to a number of milliseconds to wait
     * @maxLength 300
     */
    delayExpression?: string | null;
}
export declare enum Units {
    UNKNOWN = "UNKNOWN",
    MINUTES = "MINUTES",
    HOURS = "HOURS",
    DAYS = "DAYS"
}
export declare enum ScheduleStatus {
    UNKNOWN_SCHEDULE_STATUS = "UNKNOWN_SCHEDULE_STATUS",
    PENDING = "PENDING",
    CANCELLED = "CANCELLED",
    DONE = "DONE"
}
export interface TriggerInfo {
    /**
     * App id of the initial trigger.
     * @format GUID
     */
    appId?: string;
    /** Trigger key of the initial trigger. */
    triggerKey?: string;
}
export interface ScheduleResponse {
    /** @format GUID */
    id?: string;
}
export interface CancelPendingScheduleRequest extends CancelPendingScheduleRequestByOneOf {
    /** @format GUID */
    id?: string;
    identifier?: string;
    /** @format GUID */
    configurationCorrelationId?: string;
    /** @format GUID */
    activationId?: string;
    /**
     * @minLength 1
     * @maxLength 500
     */
    identifierPattern?: string;
}
/** @oneof */
export interface CancelPendingScheduleRequestByOneOf {
    /** @format GUID */
    id?: string;
    identifier?: string;
    /** @format GUID */
    configurationCorrelationId?: string;
    /** @format GUID */
    activationId?: string;
    /**
     * @minLength 1
     * @maxLength 500
     */
    identifierPattern?: string;
}
export interface CancelPendingScheduleResponse {
}
export interface UpdatePendingSchedulesPayloadRequest {
    identifier?: string;
    eventPayload?: string;
}
export interface UpdatePendingSchedulesPayloadResponse {
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entityAsJson?: string;
    /** Indicates the event was triggered by a restore-from-trashbin operation for a previously deleted entity */
    restoreInfo?: RestoreInfo;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntityAsJson?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntityAsJson?: string | null;
}
export interface ActionEvent {
    bodyAsJson?: string;
}
export interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
export interface ConsumeReportEventRequest {
    /**
     * Repeated list of event details for bulk reporting.
     * @minSize 1
     * @maxSize 100
     */
    eventsInfo?: EventInfo[];
    /**
     * trigger app id
     * @format GUID
     */
    triggerAppId?: string;
    /**
     * trigger key
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
}
export interface EventInfo {
    /**
     * Event payload, formatted as key:value pairs.
     * Must comply with the payload schema
     * if you provided one when configuring your trigger.
     */
    payload?: Record<string, any> | null;
    /**
     * ID of the related resource in GUID format.
     * @format GUID
     */
    externalEntityId?: string | null;
    /** Idempotency information for the event. */
    idempotency?: Idempotency;
}
export interface Idempotency {
    /**
     * A unique identifier for the event.
     * If you send the same idempotency key in multiple report event requests, for the same trigger key and app id,
     * consecutive requests will be ignored after the first one. Note that the idempotency key is kept for a week before it expires.
     * @minLength 1
     * @maxLength 80
     */
    key?: string;
    /**
     * Optional. The time to live (TTL) in milliseconds before the key will expire. Default is a week.
     * @min 1
     */
    ttlInMilliseconds?: string | null;
}
export interface BatchActivationRequest {
    /** List of Activation-Request. */
    activationRequests?: ActivationRequest[];
}
export interface ActivationRequest {
    /**
     * Activation's ID.
     * @format GUID
     */
    activationId?: string;
    /**
     * Configuration's ID.
     * @format GUID
     */
    configurationId?: string;
    /** @format GUID */
    configurationCorrelationId?: string;
    /**
     * Received event name.
     * @maxLength 80
     */
    eventName?: string;
    /**
     * Received event slug.
     * @maxLength 50
     */
    eventSlug?: string | null;
    /** Received event payload. */
    eventPayload?: string | null;
    /** List of action data. */
    actions?: ActionData[];
    /**
     * External ID.
     * @format GUID
     */
    externalId?: string;
    /** The source of this activation */
    source?: ActivationSource;
    /** Actions tree */
    actionsMap?: ActionsData;
    /** Automation V2. Used for reporting domain event until activation request will be deprecated. */
    automation?: Automation;
    /** Trigger entity for the activation, available for v2 and v3 automations only */
    triggerSchema?: Record<string, any> | null;
}
export interface Runtime {
}
export interface Scheduler {
    scheduleId?: string | null;
}
export interface AsyncAction {
}
export interface ActionData {
    /**
     * Action's id.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /** Action's data. */
    action?: Action;
}
export interface Action extends ActionActionOneOf {
    service?: Service;
    systemHelper?: SystemHelper;
    spiAction?: SpiAction;
}
/** @oneof */
export interface ActionActionOneOf {
    service?: Service;
    systemHelper?: SystemHelper;
    spiAction?: SpiAction;
}
export interface ServiceMapping {
    /** Sevice name. */
    name?: string;
    /** Method name. */
    method?: string;
}
export interface IfFilter {
    /** If filter's condition. */
    condition?: string;
    /** If's true post actions. */
    truePostActions?: ActionData[];
    /** If's false post actions. */
    falsePostActions?: ActionData[];
    /**
     * If's true post actions ids.
     * @maxSize 20
     */
    truePostActionsIds?: string[];
    /**
     * If's false post actions ids.
     * @maxSize 20
     */
    falsePostActionsIds?: string[];
}
export interface SwitchFilter {
    /** Switch's filter cases. */
    cases?: Case[];
}
export interface Case {
    /** Case's condition. */
    condition?: any;
    /** Case's post actions. */
    postActions?: ActionData[];
    /**
     * Case's post actions ids.
     * @maxSize 20
     */
    postActionsIds?: string[];
}
export interface DelayHelper {
    /** jsonata expression, for example: triggerName + eventId */
    scheduleIdentifier?: string;
    /** decide how long we should wait */
    delay?: Delay;
    /** Delay's post actions. */
    postActions?: ActionData[];
    /**
     * Optional: if true, any new schedule with the same schedule identifier will override the existing one.
     * If false, the new schedule will be ignored.
     */
    overrideable?: boolean | null;
    /**
     * Delay's post actions ids.
     * @maxSize 20
     */
    postActionsIds?: string[];
}
export interface RateLimiting {
    /** The maximum number of activations allowed in the given time frame */
    maxNumOfActivations?: number;
    /**
     * Optional, used if provided: A jsonata expression that evaluates to the maximum number of activations allowed in the given time frame
     * @maxLength 300
     */
    maxNumOfActivationsExpression?: string | null;
    /** If given - the time frame in minutes, otherwise, for life */
    timeFrameInMinutes?: number | null;
    /**
     * Optional, used if provided - A jsonata expression that evaluates to the time frame in minutes, otherwise, for life
     * @maxLength 300
     */
    timeFrameInMinutesExpression?: string | null;
    /**
     * The jsonata to use to extract the entity/resource key from the enriched event payload
     * @maxLength 1000
     */
    keyJsonata?: string;
    /**
     * The actions to perform if this rate limiting action succeeded - meaning we are still in the allowed number of activations in the given time frame
     * @maxSize 9999
     */
    postActions?: ActionData[];
    /**
     * The ids of actions to perform if this rate limiting action succeeded - meaning we are still in the allowed number of activations in the given time frame
     * @maxSize 20
     */
    postActionsIds?: string[];
}
export interface ConditionFilter {
    /**
     * condition evaluates to `true` if either of the blocks evaluate to `true` (aka OR between all).
     * @minSize 1
     * @maxSize 10
     */
    conditionBlocks?: ConditionBlock[];
    /** Actions to perform when condition_blocks evaluates to `true`. */
    postActions?: ActionData[];
    /**
     * Action's post actions ids.
     * @maxSize 20
     */
    postActionsIds?: string[];
    /**
     * Actions to perform when condition_blocks evaluates to `false`.
     * @maxSize 2000
     */
    elsePostActions?: ActionData[];
}
export declare enum BlockType {
    UNKNOWN = "UNKNOWN",
    OR = "OR",
    AND = "AND"
}
export interface ConditionBlock {
    type?: BlockType;
    /**
     * @minSize 1
     * @maxSize 20
     */
    lineExpressions?: string[];
}
export interface CodeConditionFilter {
    /** Code Snippet */
    snippet?: CodeSnippet;
    /**
     * Actions to perform when condition_blocks evaluates to `true`.
     * @maxSize 2000
     */
    postActions?: ActionData[];
    /**
     * Action's post actions ids.
     * @format GUID
     * @maxSize 20
     */
    postActionsIds?: string[];
    /**
     * Actions to perform when condition_blocks evaluates to `false`.
     * @maxSize 2000
     */
    elsePostActions?: ActionData[];
}
export interface CodeSnippet {
    /** Logical operator used to evaluate the condition expressions. */
    language?: Language;
    /**
     * Expressions evaluated using the selected operator.
     * @maxLength 1000
     */
    code?: string;
}
export declare enum Language {
    /** Unknown. */
    UNKNOWN_LANGUAGE = "UNKNOWN_LANGUAGE",
    /** `JAVASCRIPT` language. */
    JAVASCRIPT = "JAVASCRIPT"
}
export interface Output {
    /**
     * The jsonata to use to produce the output
     * @minLength 1
     * @maxLength 5000
     */
    outputMapping?: string;
}
export interface SetVariables {
    /**
     * Action's output mapping.
     * Jsonata expressions to set variables
     * for example: { "var1": "$average([10,20])", "var2": "$number($lookup($, $decodeUrlComponent(\"var1\"))) >= $number(8)"" }
     * @minLength 1
     * @maxLength 5000
     */
    outputMapping?: string;
    /**
     * Action's post actions.
     * @maxSize 20
     */
    postActions?: ActionData[];
    /**
     * Action's post actions ids.
     * @format GUID
     * @maxSize 20
     */
    postActionsIds?: string[];
    /**
     * The namespace of the action
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
    /** Json Schema for the output mapping */
    outputSchema?: Record<string, any> | null;
}
export interface Service {
    /** Action's service mapping. */
    serviceMapping?: ServiceMapping;
    /**
     * Action's input mapping.
     * Jsonata description of the input this service gets.
     */
    inputMapping?: string | null;
    /**
     * Action's output mapping.
     * Jsonata description of the output this service returns.
     */
    outputMapping?: string | null;
    /** Action's post actions. */
    postActions?: ActionData[];
    /**
     * Action's post actions ids.
     * @maxSize 20
     */
    postActionsIds?: string[];
    /**
     * The namespace of the action
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
}
export interface SystemHelper extends SystemHelperHelperOneOf {
    ifFilter?: IfFilter;
    switchFilter?: SwitchFilter;
    delay?: DelayHelper;
    rateLimiting?: RateLimiting;
    conditionFilter?: ConditionFilter;
    codeConditionFilter?: CodeConditionFilter;
    output?: Output;
    setVariables?: SetVariables;
}
/** @oneof */
export interface SystemHelperHelperOneOf {
    ifFilter?: IfFilter;
    switchFilter?: SwitchFilter;
    delay?: DelayHelper;
    rateLimiting?: RateLimiting;
    conditionFilter?: ConditionFilter;
    codeConditionFilter?: CodeConditionFilter;
    output?: Output;
    setVariables?: SetVariables;
}
export interface SpiAction {
    /** The App Def Id of the action provider */
    appDefId?: string;
    /** Identifier for this action - human readable action key - unique per app def id */
    actionKey?: string;
    /** The configuration of the user for this action, can include params that are taken from the trigger event payload */
    userActionConfig?: string | null;
    /** The post action to execute after this action */
    postActions?: ActionData[];
    /** The output configuration of the user for this action, can include params that are taken from the trigger event payload */
    userOutputActionConfig?: string | null;
    /**
     * optional skip condition expression for current action
     * decides whether to skip the action before executing it's post actions
     * @maxLength 1000
     */
    skipConditionExpression?: string | null;
    /**
     * Action's post actions ids.
     * @maxSize 20
     */
    postActionsIds?: string[];
    /**
     * The namespace of the action
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
}
export interface ActivationSource extends ActivationSourceOfOneOf {
    runtime?: Runtime;
    scheduler?: Scheduler;
    asyncAction?: AsyncAction;
}
/** @oneof */
export interface ActivationSourceOfOneOf {
    runtime?: Runtime;
    scheduler?: Scheduler;
    asyncAction?: AsyncAction;
}
export interface ActionsData {
    /**
     * Ids of the first level actions.
     * @maxSize 20
     */
    rootActionIds?: string[];
    /** Map of action id to action data. */
    actions?: Record<string, Action>;
}
export interface ActivationScheduleRequested {
    /**
     * Activation identifier
     * @format GUID
     */
    id?: string;
    /** Activation schedule request date */
    requestedDate?: Date | null;
    /** Activation schedule due date */
    scheduleDate?: Date | null;
    /** Activation payload */
    payload?: Record<string, any> | null;
    /** Activation Automation */
    automation?: Automation;
    /**
     * Optional - external entity id that this activation is related to
     * @format GUID
     */
    externalEntityId?: string | null;
}
export interface ScheduleActivationRequested {
    /**
     * Activation identifier
     * @format GUID
     * @immutable
     */
    id?: string;
    /**
     * Optional - external entity id that this activation is related to
     * @format GUID
     * @immutable
     */
    externalEntityId?: string | null;
    /**
     * Activation payload
     * @immutable
     */
    payload?: Record<string, any> | null;
    /**
     * Activation Automation
     * @immutable
     */
    automation?: Automation;
    /**
     * Activation schedule date
     * @immutable
     */
    scheduleDate?: Date | null;
}
export interface ActivationContinuedAfterSchedule {
    /**
     * Activation identifier
     * @format GUID
     */
    id?: string;
    /** Activation Automation */
    automation?: Automation;
}
export interface ReportEventRequest {
    /**
     * Trigger key as defined in your app's trigger configuration
     * in the app dashboard.
     * For example, `form_submitted` or `invoice_due`.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey: string;
    /**
     * Event payload, formatted as key:value pairs.
     * Must comply with the payload schema
     * if you provided one when configuring your trigger.
     *
     * Key names can include only alphanumeric characters or underscores
     * (`A-Z`, `a-z`, `0-9`, `_`).
     * They cannot start with an underscore.
     *
     * Values can be strings, numbers, integers, booleans, or arrays.
     * If a value is an array, the array items must be objects,
     * and nested object properties must be
     * strings, numbers, integers, or booleans only.
     */
    payload?: Record<string, any> | null;
    /**
     * ID of the related resource in GUID format.
     * For example, `fc81a355-3429-50fc-a4c7-def486e828f3`.
     *
     * Required if your app needs to
     * [cancel the event](https://dev.wix.com/docs/rest/business-management/automations/triggered-events/cancel-event)
     * if the automation becomes no longer relevant.
     *
     * Typically, this ID is defined in your system,
     * but you can also use any Wix resource GUID,
     * such as contact ID, member ID, or invoice ID.
     * See
     * [Choose the right `externalEntityId`](https://dev.wix.com/docs/rest/business-management/automations/triggered-events/reporting-and-canceling-events#about-canceling-events)
     * for more information.
     * @format GUID
     */
    externalEntityId?: string | null;
    /** Idempotency information for the event. */
    idempotency?: Idempotency;
}
export interface ReportEventResponse {
    /**
     * The activation IDs of triggered ReportEvents.
     * @maxSize 100
     * @format GUID
     */
    activationIds?: string[];
}
export interface BulkReportEventRequest {
    /**
     * Trigger key as defined in your app's trigger configuration
     * in the app dashboard.
     * For example, `form_submitted` or `invoice_due`.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey: string;
    /**
     * Repeated list of event details for bulk reporting.
     * @minSize 1
     * @maxSize 100
     */
    eventsInfo: EventInfo[];
}
export interface BulkReportEventResponse {
    /**
     * Trigger key associated with the event.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /** List of results for each item in the bulk report event request. */
    results?: BulkReportEventResult[];
    /** Metadata for the overall bulk action, including success and failure counts. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkReportEventResult {
    /** Metadata for the individual item in the request. */
    itemMetadata?: ItemMetadata;
    /** Event details for the item in the request. */
    eventInfo?: EventInfo;
    /**
     * The activation IDs of triggered ReportEvents.
     * @maxSize 100
     * @format GUID
     */
    activationIds?: string[];
}
export interface ItemMetadata {
    /** Item ID. Should always be available, unless it's impossible (for example, when failing to create an item). */
    id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
export interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
export interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
export interface BulkCancelEventRequest {
    /**
     * Trigger key whose events you want to cancel.
     * For example, `form_submitted` or `invoice_due`.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey: string;
    /**
     * Repeated list of external_entity_id, representing the related resources' IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    externalEntityIds: string[];
}
export interface BulkCancelEventResponse {
    /**
     * Trigger key related to the canceled event.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /** List of results for each item in the bulk cancel event request. */
    results?: BulkCancelEventResult[];
    /** Metadata for the overall bulk action, including success and failure counts. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkCancelEventResult {
    /** Metadata of the item, including its ID and success or failure status. */
    itemMetadata?: ItemMetadata;
    /**
     * ID of the related resource in GUID format.
     * @format GUID
     */
    externalEntityId?: string;
}
export interface CancelEventRequest {
    /**
     * ID of the related resource in GUID format.
     * For example, `fc81a355-3429-50fc-a4c7-def486e828f3`.
     *
     * Typically, this ID is defined in your system,
     * but you can also use any Wix resource GUID,
     * such as contact ID, member ID, or invoice ID.
     * See
     * [Choose the right `externalEntityId`](https://dev.wix.com/docs/rest/business-management/automations/triggered-events/reporting-and-canceling-events#choose-the-right-externalentityid)
     * for more information.
     * @format GUID
     */
    externalEntityId: string;
    /**
     * Trigger key whose event you want to cancel.
     * For example, `form_submitted` or `invoice_due`.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey: string;
}
export interface CancelEventResponse {
}
export interface V1RunAutomationRequest extends V1RunAutomationRequestIdentifierOneOf {
    /** a preinstalled automation identifier */
    preinstalledIdentifier?: PreinstalledIdentifier;
    /** a automation of any type identifier that will be available in future */
    automationIdentifier?: AutomationIdentifier;
    /**
     * identifier MUST be either AUTOMATION or PREINSTALLED
     * @immutable
     */
    identifierType?: IdentifierType;
    /**
     * Event payload, formatted as key:value pairs.
     * Must comply with the payload schema
     * if you provided one when configuring your trigger.
     *
     * Key names can include only alphanumeric characters or underscores
     * (`A-Z`, `a-z`, `0-9`, `_`).
     * They cannot start with an underscore.
     *
     * Values can be strings, numbers, integers, booleans, or arrays.
     * If a value is an array, the array items must be objects,
     * and nested object properties must be
     * strings, numbers, integers, or booleans only.
     */
    payload?: Record<string, any> | null;
}
/** @oneof */
export interface V1RunAutomationRequestIdentifierOneOf {
    /** a preinstalled automation identifier */
    preinstalledIdentifier?: PreinstalledIdentifier;
    /** a automation of any type identifier that will be available in future */
    automationIdentifier?: AutomationIdentifier;
}
export declare enum IdentifierType {
    UNKNOWN_IDENTIFIER = "UNKNOWN_IDENTIFIER",
    PREINSTALLED = "PREINSTALLED",
    AUTOMATION = "AUTOMATION"
}
export interface PreinstalledIdentifier {
    /**
     * identifier for the application of the preinstalled
     * @format GUID
     */
    appId?: string;
    /**
     * application component id
     * @format GUID
     */
    componentId?: string;
}
export interface AutomationIdentifier {
    /**
     * automation id
     * @format GUID
     */
    automationId?: string;
}
export interface V1RunAutomationResponse {
}
export interface ReportDomainEventRequest {
    /**
     * trigger app id
     * @format GUID
     */
    triggerAppId?: string;
    /** report event request */
    reportEventRequest?: ReportEventRequest;
}
export interface ReportDomainEventResponse {
}
export interface ExecuteFromActionRequest {
    /**
     * Requested action id
     * @format GUID
     */
    actionId?: string;
    /**
     * Optional: an activation id to link this action to
     * @format GUID
     */
    activationId?: string | null;
    /** Activation payload */
    payload?: Record<string, any> | null;
    /**
     * Configuration correlation id to run this action from
     * @format GUID
     */
    configurationCorrelationId?: string;
    /**
     * Optional - schedule id that this action was scheduled from
     * @format GUID
     */
    scheduleId?: string | null;
    /**
     * Optional - an external entity id that this execution is related to
     * @format GUID
     */
    externalEntityId?: string | null;
    /** Optional - Activation automation */
    automation?: Automation;
}
export interface ExecuteFromActionResponse {
}
export interface Empty {
}
export interface ActivationScheduleCompleted {
    /**
     * Activation identifier
     * @format GUID
     */
    id?: string;
    /**
     * Activation schedule identifier
     * @format GUID
     */
    scheduleId?: string;
    /** Activation schedule due date */
    scheduleDate?: Date | null;
    /** Activation payload */
    payload?: Record<string, any> | null;
    /** Activation Automation */
    automation?: Automation;
    /**
     * Optional - external entity id that this activation is related to
     * @format GUID
     */
    externalEntityId?: string | null;
}
export interface ActionRetryRequest {
    /** The activation context */
    activationContext?: ActivationContext;
    /** The action to retry */
    actionToRetryData?: ActionData;
}
export interface ActivationContext {
    /**
     * Activation ID
     * @format GUID
     */
    activationId?: string;
    /**
     * Action ID
     * @format GUID
     */
    actionId?: string;
    /**
     * Configuration ID
     * @format GUID
     */
    configurationId?: string;
    /**
     * Configuration Correlation ID
     * @format GUID
     */
    configurationCorrelationId?: string;
    /** name of the event. intended to keep backwards compatibility, probably not in use. */
    eventName?: string;
    /** Event slug, also probably not in use */
    eventSlug?: string | null;
    /** Enriched event payload */
    enrichedEventPayload?: string;
    /** Raw event payload */
    rawEventPayload?: string;
    /** Actions */
    actions?: ActionData[];
    /** Activation status */
    activationStatus?: RuntimeStatus;
    /** External ID */
    externalId?: string;
    /** Automation */
    automationV2?: Automation;
    /** Output */
    output?: string | null;
}
export declare enum RuntimeStatus {
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    STARTED = "STARTED",
    ENDED = "ENDED",
    ERROR = "ERROR",
    SCHEDULED = "SCHEDULED",
    FROM_SCHEDULER = "FROM_SCHEDULER",
    RETRY = "RETRY",
    RESUMED = "RESUMED",
    PAUSED = "PAUSED",
    ACTION_SKIPPED = "ACTION_SKIPPED"
}
export interface ResumeAfterAsyncActionCompleted extends ResumeAfterAsyncActionCompletedStatusInfoOneOf {
    /** Success info */
    successInfo?: SuccessInfo;
    /** Fail info */
    failureInfo?: FailureInfo;
    /**
     * External ID
     * @format GUID
     */
    externalId?: string | null;
    /** Payload */
    payload?: Record<string, any> | null;
    /** Automation */
    automation?: Automation;
    /**
     * Activation ID
     * @format GUID
     */
    activationId?: string;
    /**
     * Action ID
     * @format GUID
     */
    actionId?: string;
    /** Result status */
    status?: Status;
}
/** @oneof */
export interface ResumeAfterAsyncActionCompletedStatusInfoOneOf {
    /** Success info */
    successInfo?: SuccessInfo;
    /** Fail info */
    failureInfo?: FailureInfo;
}
export declare enum Status {
    /** Unknown action completion status. */
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** Action completed successfully. */
    SUCCESS = "SUCCESS",
    /** Action failed to complete. */
    FAILURE = "FAILURE"
}
export interface SuccessInfo {
    /** Result object that correlates to the output schema. */
    result?: Record<string, any> | null;
}
export interface FailureInfo {
    /**
     * Description of the error that caused the action to fail.
     * @maxLength 1000
     */
    errorDescription?: string;
}
export interface ActivationActionStatusChanged extends ActivationActionStatusChangedInfoOneOf, ActivationActionStatusChangedStatusInfoOneOf {
    /** App defined action info */
    appDefinedInfo?: AppDefinedActionInfo;
    /** Started status information */
    startedInfo?: StartedStatusInfo;
    /** Invoked status information */
    invokedAsyncInfo?: InvokedAsyncStatusInfo;
    /** Ended status information */
    endedInfo?: EndedStatusInfo;
    /** Failed status information */
    failedInfo?: FailedStatusInfo;
    /**
     * Action ID
     * @format GUID
     */
    id?: string;
    /**
     * Activation ID
     * @format GUID
     */
    activationId?: string;
    /** Automation info */
    automationInfo?: AutomationInfo;
    /** Action type */
    type?: Type;
    /** Action attributes */
    attributes?: ActionAttributes;
    /**
     * External entity ID
     * @maxLength 40
     */
    externalEntityId?: string | null;
    /** Event date */
    statusChangedDate?: Date | null;
    /** Action activation status */
    status?: ActivationActionStatusChangedStatus;
}
/** @oneof */
export interface ActivationActionStatusChangedInfoOneOf {
    /** App defined action info */
    appDefinedInfo?: AppDefinedActionInfo;
}
/** @oneof */
export interface ActivationActionStatusChangedStatusInfoOneOf {
    /** Started status information */
    startedInfo?: StartedStatusInfo;
    /** Invoked status information */
    invokedAsyncInfo?: InvokedAsyncStatusInfo;
    /** Ended status information */
    endedInfo?: EndedStatusInfo;
    /** Failed status information */
    failedInfo?: FailedStatusInfo;
}
export interface RetryInfo {
}
export interface StartedStatusInfoAppDefinedActionInfo {
    /** Action input */
    input?: Record<string, any> | null;
}
export interface StartedStatusInfoDelayActionInfo {
    /** Indicates when this action becomes completed and the activation will move to the post actions */
    date?: Date | null;
}
export interface InvokedAsyncStatusInfoAppDefinedActionInfo {
    /** Default action output, in case we reach the timeout before provider called complete action activation method */
    output?: Record<string, any> | null;
    /** Timeout date */
    timeoutDate?: Date | null;
}
export interface ExpressionEvaluationResult {
    /** Indicates if the expression was evaluated to true or false */
    passed?: boolean;
    /** Indicates if there was an error in the evaluation process */
    error?: boolean;
}
export interface EndedStatusInfoAppDefinedActionInfo {
    /** Output returned by the action implementer. */
    output?: Record<string, any> | null;
}
export interface ConditionActionInfo {
    /** Indicates that the condition `if` clause evaluated to `true`. */
    passed?: boolean;
    /** Collects results per each expression evaluation that took place */
    expressionResults?: Record<string, ExpressionEvaluationResult>;
}
export interface CodeConditionActionInfo {
    /** Indicates that the code condition `if` clause evaluated to `true`. */
    passed?: boolean;
}
export interface RateLimitActionInfo {
    /** Indicates if the rate limiter passed (not reached the quota) */
    passed?: boolean;
}
export interface DelayActionInfo {
    /** Enriched and refreshed payload */
    payload?: Record<string, any> | null;
}
export interface SetVariablesActionInfo {
    /** Output returned after jsonata expression evaluation */
    output?: Record<string, any> | null;
}
export interface AutomationInfo extends AutomationInfoOriginInfoOneOf {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
    /**
     * Automation ID
     * @format GUID
     */
    id?: string;
    /** Origin type */
    origin?: Origin;
    /** Trigger info */
    triggerInfo?: AutomationInfoTriggerInfo;
}
/** @oneof */
export interface AutomationInfoOriginInfoOneOf {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
}
export interface AutomationInfoTriggerInfo {
    /**
     * Trigger app ID
     * @format GUID
     */
    appId?: string;
    /**
     * Trigger key
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
}
export interface ActionAttributes {
    /**
     * Indicates if this action run is part of a retry attempt
     * If it's not null, it's a retry action run
     */
    retry?: RetryInfo;
}
export interface AppDefinedActionInfo {
    /**
     * Action app ID
     * @format GUID
     */
    appId?: string;
    /**
     * Action key
     * @minLength 1
     * @maxLength 100
     */
    actionKey?: string;
}
export declare enum ActivationActionStatusChangedStatus {
    UNKNOWN_ACTION_ACTIVATION_STATUS = "UNKNOWN_ACTION_ACTIVATION_STATUS",
    /**
     * Indicates that action activation has started and is in progress.
     * Relevant to action types: APP_DEFINED, DELAY.
     */
    STARTED = "STARTED",
    /** Indicates that async action was invoked and now waiting to be completed */
    INVOKED_ASYNC = "INVOKED_ASYNC",
    /**
     * Indicates that the action activation was completed without errors.
     * Relevant to action types: APP_DEFINED, DELAY, CONDITION, RATE_LIMIT.
     */
    ENDED = "ENDED",
    /**
     * Indicates that the action was skipped and post actions won't start.
     * Relevant to action types: APP_DEFINED.
     */
    SKIPPED = "SKIPPED",
    /**
     * Indicates that the action failed.
     * Relevant to action types: APP_DEFINED, DELAY, RATE_LIMIT.
     */
    FAILED = "FAILED"
}
export interface StartedStatusInfo extends StartedStatusInfoTypeInfoOneOf {
    /** APP DEFINED action additional info */
    appDefinedActionInfo?: StartedStatusInfoAppDefinedActionInfo;
    /** Delay action additional info */
    delayActionInfo?: StartedStatusInfoDelayActionInfo;
}
/** @oneof */
export interface StartedStatusInfoTypeInfoOneOf {
    /** APP DEFINED action additional info */
    appDefinedActionInfo?: StartedStatusInfoAppDefinedActionInfo;
    /** Delay action additional info */
    delayActionInfo?: StartedStatusInfoDelayActionInfo;
}
export interface InvokedAsyncStatusInfo extends InvokedAsyncStatusInfoTypeInfoOneOf {
    /** APP DEFINED action additional info */
    appDefinedActionInfo?: InvokedAsyncStatusInfoAppDefinedActionInfo;
}
/** @oneof */
export interface InvokedAsyncStatusInfoTypeInfoOneOf {
    /** APP DEFINED action additional info */
    appDefinedActionInfo?: InvokedAsyncStatusInfoAppDefinedActionInfo;
}
export interface EndedStatusInfo extends EndedStatusInfoTypeInfoOneOf {
    /** APP DEFINED action additional info */
    appDefinedActionInfo?: EndedStatusInfoAppDefinedActionInfo;
    /** Condition action additional info */
    conditionActionInfo?: ConditionActionInfo;
    /** Code Condition action additional info */
    codeConditionActionInfo?: CodeConditionActionInfo;
    /** Rate limit action additional info */
    rateLimitActionInfo?: RateLimitActionInfo;
    /** Delay action additional info */
    delayActionInfo?: DelayActionInfo;
    /** Set Variables action additional info */
    setVariablesActionInfo?: SetVariablesActionInfo;
}
/** @oneof */
export interface EndedStatusInfoTypeInfoOneOf {
    /** APP DEFINED action additional info */
    appDefinedActionInfo?: EndedStatusInfoAppDefinedActionInfo;
    /** Condition action additional info */
    conditionActionInfo?: ConditionActionInfo;
    /** Code Condition action additional info */
    codeConditionActionInfo?: CodeConditionActionInfo;
    /** Rate limit action additional info */
    rateLimitActionInfo?: RateLimitActionInfo;
    /** Delay action additional info */
    delayActionInfo?: DelayActionInfo;
    /** Set Variables action additional info */
    setVariablesActionInfo?: SetVariablesActionInfo;
}
export interface FailedStatusInfo {
    /**
     * Error description
     * @maxLength 1000
     */
    errorDescription?: string;
    /**
     * Error code
     * @maxLength 20
     */
    errorCode?: string | null;
}
export interface ActivationResumeAfterDelay {
    /**
     * Activation identifier
     * @format GUID
     */
    id?: string;
    /**
     * Activation schedule identifier
     * @format GUID
     */
    scheduleId?: string;
    /** Activation schedule due date */
    scheduleDate?: Date | null;
    /** Activation payload */
    payload?: Record<string, any> | null;
    /** Activation Automation */
    automation?: Automation;
    /**
     * Scheduled action identifier - with the intent to execute that action's post actions
     * @format GUID
     */
    scheduledActionId?: string;
    /**
     * Optional - external entity id that this activation is related to
     * @format GUID
     */
    externalEntityId?: string | null;
}
export interface ActionCompletedRequest {
    /** The execution identifier that was given to the spi provider when we invoked the action */
    executionIdentifier?: string;
    /** The result of invoking the action. Must conform to the output schema configured by the action provider. */
    result?: Record<string, any> | null;
}
export interface RefreshPayloadRequest {
    /**
     * Application definition ID.
     * @format GUID
     */
    appDefId?: string;
    /** Trigger key. */
    triggerKey?: string;
    /** Payload to refresh. */
    payload?: Record<string, any> | null;
    /** External entity ID. */
    externalEntityId?: string | null;
}
export interface RefreshPayloadResponse {
    /** Updated payload. */
    payload?: Record<string, any> | null;
    /** If the automation activation should be canceled (default is false) */
    cancelActivation?: boolean | null;
}
export interface RunAutomationRequest {
    /**
     * App of the automation trigger
     * @format GUID
     */
    appId?: string;
    /**
     * Trigger key of the action
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /** Payload of the triggered event */
    triggerPayload?: Record<string, any> | null;
    /**
     * Specific automation id to run
     * @format GUID
     */
    automationId?: string;
    /** Schema of the trigger */
    triggerSchema?: Record<string, any> | null;
    /** Skip retry mechanism. If set to true, we will not retry the automations actions in case of a retryable error. */
    skipRetry?: boolean | null;
}
export interface RunAutomationResponse {
    /** Automation activation output payload */
    output?: Record<string, any> | null;
}
export interface ReportActionInvocationCompletedRequest extends ReportActionInvocationCompletedRequestStatusInfoOneOf {
    /** Action output data as defined in your action [output schema](https://dev.wix.com/docs/rest/business-management/automations/actions/about-actions#the-output-schema). */
    successInfo?: SuccessInfo;
    /** Information about the action's failure to complete. */
    failureInfo?: FailureInfo;
    /** Action completion status. */
    status?: Status;
    /**
     * Invocation token.
     * @maxLength 500
     */
    invocationToken?: string;
}
/** @oneof */
export interface ReportActionInvocationCompletedRequestStatusInfoOneOf {
    /** Action output data as defined in your action [output schema](https://dev.wix.com/docs/rest/business-management/automations/actions/about-actions#the-output-schema). */
    successInfo?: SuccessInfo;
    /** Information about the action's failure to complete. */
    failureInfo?: FailureInfo;
}
export interface ReportActionInvocationCompletedResponse {
}
